get_thermalsafetymargin: Estimate thermal safety margin of a thermal performance curve
Description
Estimate thermal safety margin of a thermal performance curve
Usage
get_thermalsafetymargin(model)
Value
Numeric estimate of thermal safety margin (in ºC)
Arguments
- model
nls model object that contains a model of a thermal performance curve
Details
Thermal safety margin is calculated as: CTmax - Topt. This is calculated using the functions get_ctmax and get_topt.