Learn R Programming

rTPC (version 1.0.4)

kamykowski_1985: Kamykowski model for fitting thermal performance curves

Description

Kamykowski model for fitting thermal performance curves

Usage

kamykowski_1985(temp, tmin, tmax, a, b, c)

Value

a numeric vector of rate values based on the temperatures and parameter values provided to the function

Arguments

temp

temperature in degrees centigrade

tmin

low temperature (ºC) at which rates become negative

tmax

high temperature (ºC) at which rates become negative

a

parameter with no biological meaning

b

parameter with no biological meaning

c

parameter with no biological meaning

Details

Equation: $$rate= a \cdot \big( 1 - exp^{-b\cdot \big(temp-t_{min}\big)}\big) \cdot \big( 1-exp^{-c \cdot \big(t_{max}-temp\big)}\big)$$

Start values in get_start_vals are derived from the data or sensible values from the literature.

Limits in get_lower_lims and get_upper_lims are derived from the data or based extreme values that are unlikely to occur in ecological settings.

References

Kamykowski, Daniel. A survey of protozoan laboratory temperature studies applied to marine dinoflagellate behaviour from a field perspective. Contributions in Marine Science. (1985).

Examples

Run this code
# load in ggplot
library(ggplot2)

# subset for the first TPC curve
data('chlorella_tpc')
d <- subset(chlorella_tpc, curve_id == 1)

# get start values and fit model
start_vals <- get_start_vals(d$temp, d$rate, model_name = 'kamykowski_1985')
# fit model
mod <- nls.multstart::nls_multstart(rate~kamykowski_1985(temp = temp, tmin, tmax, a, b, c),
data = d,
iter = c(3,3,3,3,3),
start_lower = start_vals - 10,
start_upper = start_vals + 10,
lower = get_lower_lims(d$temp, d$rate, model_name = 'kamykowski_1985'),
upper = get_upper_lims(d$temp, d$rate, model_name = 'kamykowski_1985'),
supp_errors = 'Y',
convergence_count = FALSE)

# look at model fit
summary(mod)

# get predictions
preds <- data.frame(temp = seq(min(d$temp), max(d$temp), length.out = 100))
preds <- broom::augment(mod, newdata = preds)

# plot
ggplot(preds) +
geom_point(aes(temp, rate), d) +
geom_line(aes(temp, .fitted), col = 'blue') +
theme_bw()

Run the code above in your browser using DataLab